<?php
/**
 * @package WordPress
 * @subpackage Devine
 */

/**
 * Returns an array of system fonts
 * Feel free to edit this, update the font fallbacks, etc.
 */
 
function options_typography_get_os_fonts() {
    // OS Font Defaults
    $os_faces = array(
        'Arial, sans-serif' => 'Arial',
        '"Avant Garde", sans-serif' => 'Avant Garde',
        'Cambria, Georgia, serif' => 'Cambria',
        'Copse, sans-serif' => 'Copse',
        'Garamond, "Hoefler Text", Times New Roman, Times, serif' => 'Garamond',
        'Georgia, serif' => 'Georgia',
        'Helvetica Neue, Helvetica, sans-serif' => 'Helvetica Neue',
        'Tahoma, Geneva, sans-serif' => 'Tahoma'
    );
    return $os_faces;
}


/**
 * Checks font options to see if a Google font is selected.
 * If so, options_typography_enqueue_google_font is called to enqueue the font.
 * Ensures that each Google font is only enqueued once.
 */
  
if ( !function_exists( 'options_typography_google_fonts' ) ) {
    function options_typography_google_fonts() {
    	global $data;
        $all_google_fonts = array_keys( options_typography_get_google_fonts() );
        // Define all the options that possibly have a unique Google font
		
		$default_body_font = $data['hb_default_body_font'];
    $default_main_nav_font = $data['hb_main_nav_font'];
    $default_h1_font = $data['hb_h1_font'];
    $default_h2_font = $data['hb_h2_font'];
    $default_h3_font = $data['hb_h3_font'];
    $default_h4_font = $data['hb_h4_font'];
    $default_h5_font = $data['hb_h5_font'];
    $default_h6_font = $data['hb_h6_font'];
    $default_logo_text_font = $data['hb_logo_text_font'];
    $default_logo_tagline_font = $data['hb_logo_tagline_font'];
    $default_page_title_font = $data['hb_page_title_font'];
    $default_page_subtitle_font = $data['hb_page_subtitle_font'];
    $default_footer_widget_title_font = $data['hb_footer_widget_title_font'];
    $default_footer_text_font = $data['hb_footer_text_font'];
    $default_buttons_font = $data['hb_buttons_font'];

        /*
        $google_font = of_get_option('google_font', 'Rokkitt, serif');
        $google_mixed = of_get_option('google_mixed', false);
        $google_mixed_2 = of_get_option('google_mixed_2', 'Arvo, serif');*/
       
        // Get the font face for each option and put it in an array
        $selected_fonts = array(
            $default_body_font['face'],
            $default_main_nav_font['face'],
            $default_h1_font['face'],
            $default_h2_font['face'],
            $default_h3_font['face'],
            $default_h4_font['face'],
            $default_h5_font['face'],
            $default_h6_font['face'],
            $default_logo_text_font['face'],
            $default_logo_tagline_font['face'],
            $default_page_title_font['face'],
            $default_page_subtitle_font['face'],
            $default_footer_widget_title_font['face'],
            $default_footer_text_font['face'],
            $default_buttons_font['face'],
			);
        // Remove any duplicates in the list
        $selected_fonts = array_unique($selected_fonts);
        // Check each of the unique fonts against the defined Google fonts
        // If it is a Google font, go ahead and call the function to enqueue it
        foreach ( $selected_fonts as $font ) {
            if ( in_array( $font, $all_google_fonts ) ) {
            	if ($data['hb_enable_custom_typo'])
                options_typography_enqueue_google_font($font);
            }
        }

    }
}
 
add_action( 'wp_enqueue_scripts', 'options_typography_google_fonts' );
 
 
/**
 * Enqueues the Google $font that is passed
 */
  
function options_typography_enqueue_google_font($font) {
    $font = explode(',', $font);
    $font = $font[0];
    $font = str_replace(" ", "+", $font);
	
    wp_enqueue_style( "options_typography_$font", "http://fonts.googleapis.com/css?family=$font", false, null, 'all' );
}

/* 
 * Outputs the selected option panel styles inline into the <head>
 */
  
function options_typography_styles() {
     $output = '';
     $input = '';

     global $data;
 
     /*if ( $data[ 'google_font' ] ) {
          $input = $data[ 'google_font' ];
      $output .= options_typography_font_styles( $data[ 'google_font' ] , '.google-font');
     }*/

    if ( $data['hb_default_body_font'] ) {
     $output .= options_typography_font_styles( $data['hb_default_body_font'] , 'body, p');
    }
    if ( $data['hb_main_nav_font'] ) {
      $output .= options_typography_font_styles( $data['hb_main_nav_font'] , '#main-nav li a');
    }
    if ( $data['hb_h1_font'] ) {
      $output .= options_typography_font_styles( $data['hb_h1_font'] , 'h1');
    }
    if ( $data['hb_h2_font'] ) {
      $output .= options_typography_font_styles( $data['hb_h2_font'] , 'h2');
    }
    if ( $data['hb_h3_font'] ) {
      $output .= options_typography_font_styles( $data['hb_h3_font'] , 'h3');
    }
    if ( $data['hb_h4_font'] ) {
      $output .= options_typography_font_styles( $data['hb_h4_font'] , 'h4');
    }
    if ( $data['hb_h5_font'] ) {
      $output .= options_typography_font_styles( $data['hb_h5_font'] , 'h5');
    }
    if ( $data['hb_h6_font'] ) {
      $output .= options_typography_font_styles( $data['hb_h6_font'] , 'h6');
    }
    if ( $data['hb_logo_text_font'] ) {
      $output .= options_typography_font_styles( $data['hb_logo_text_font'] , 'h1.logo-text a');
    }
    if ( $data['hb_logo_tagline_font'] ) {
      $output .= options_typography_font_styles( $data['hb_logo_tagline_font'] , 'h4#logo-tagline');
    }
    if ( $data['hb_page_title_font'] ) {
      $output .= options_typography_font_styles( $data['hb_page_title_font'] , '.main-page-title h1');
    }
    if ( $data['hb_page_subtitle_font'] ) {
      $output .= options_typography_font_styles( $data['hb_page_subtitle_font'] , 'h3.sub-title');
    }
    if ( $data['hb_footer_widget_title_font'] ) {
      $output .= options_typography_font_styles( $data['hb_footer_widget_title_font'] , '#footer-inner .widget-item h4.widget-title-inner');
    }
    if ( $data['hb_footer_text_font'] ) {
      $output .= options_typography_font_styles( $data['hb_footer_text_font'] , '#footer-inner');
    }
    if ( $data['hb_buttons_font'] ) {
      $output .= options_typography_font_styles( $data['hb_buttons_font'] , '.hb-button, input[type=submit], button');
    }
   
	 
 
     if ( $output != '' ) {
    $output = "\n<style>\n" . $output . "</style>\n";
	
	if ( !$data['hb_enable_custom_typo'] ){
		$output = '';
	}
    
	echo $output;
     }
}
add_action('wp_head', 'options_typography_styles');

/* 
 * Returns a typography option in a format that can be outputted as inline CSS
 */
  
function options_typography_font_styles($option, $selectors) {
		global $data;
		
        $output = $selectors . ' {';
        if ( isset($option['color']) && $option['color'] )
          $output .= ' color:' . $option['color'] .'; ';

        if ( isset($option['face']) && $option['face'] )
            $output .= 'font-family:' . $option['face'] . '; ';

        if ( isset($option['style']) && $option['style'] )
            $output .= 'font-weight:' . $option['style'] . '; ';

        if ( isset($option['size']) && $option['size'] )
            $output .= 'font-size:' . $option['size'] . '; ';

        if ( isset($option['height']) && $option['height'] )
            $output .= 'line-height:' . $option['height'] . '; ';

        if ( isset($option['transform']) && $option['transform'] )
           $output .= 'text-transform:' . $option['transform'] . '; ';

        $output .= '}';
        $output .= "\n";
		
		if ( !$data['hb_enable_custom_typo'] ){
			$output = '';
		}
        return $output;
}
?>