<?php
/**
 * @package WordPress
 * @subpackage BulletPress
 */

function hb_page_title ( $post_id ) {
	if ( !is_page() && !is_single() ) return;
	if ( get_post_meta ( $post_id , 'hb_disable_title' , true )	) return;
	
	$page_title = get_the_title ( $post_id );
	$page_subtitle = '';
	
	if ( get_post_meta ( $post_id , 'hb_custom_page_title' , true ) ) 
		$page_title = get_post_meta ( $post_id , 'hb_custom_page_title' , true );
		
	if ( get_post_meta ( $post_id , 'hb_custom_page_subtitle' , true ) )
		$page_subtitle = get_post_meta ( $post_id , 'hb_custom_page_subtitle' , true );
	?>

	<?php
	if ( !is_user_logged_in() && get_post_meta( $post_id , 'hb_post_login_required' , true ) ) {
		$page_title = __('Login Required' , 'hbthemes');
	}

	if ( get_current_template(get_the_ID()) == 'page-login.php' ) {
		if ( !is_user_logged_in() ) $page_title = __('Login','hbthemes');
		else $page_title = __('Logout','hbthemes');
	}
	?>

	<?php if ( !$page_title ) return; ?>
	<div class="page-title-box main-page-title clearfix">
		<h1 class="page-title"><?php echo $page_title; ?></h1>
	</div>
	

	<?php if ( $page_subtitle ) { ?>
	<h3 class="sub-title floatleft"><?php echo $page_subtitle; ?></h3>
	<div class="clear"></div>
	<?php }	
	do_action('hb_after_title');

}
add_action('page_custom_before_content' , 'hb_page_title' , 10, 1);

function hb_archives_title() {	
	$page_title = '';
	$page_subtitle = '';
	global $wp_query;
	global $data;
	
	if ( is_category() ) {
		$page_title = single_cat_title ('' , false);	
		if ( !have_posts() )
			//$page_subtitle = sprintf(__('Showing %s of %s posts' , 'hbthemes'), $wp_query->post_count , $wp_query->found_posts);
		
			$page_subtitle = __('There are no posts for this category' , 'hbthemes');	
	} else if ( is_day() ) {
		$page_title = __('Daily Archives' , 'hbthemes');
		$page_subtitle = get_the_time ( 'd F Y' );
	} else if ( is_month() ) {
		$page_title = __('Monthly Archives' , 'hbthemes');
		$page_subtitle = get_the_time ( 'F Y' );
	} else if ( is_year() ) {
		$page_title = __('Yearly Archives' , 'hbthemes');
		$page_subtitle = get_the_time ( 'Y' );
	} else if ( is_search() ) {
		$page_title = __( 'Search Completed ', 'hbthemes' );
		$page_subtitle = sprintf( __( 'There are %s results found' , 'hbthemes') , $wp_query->found_posts );
	} else if ( is_tag() ) {
		$page_title = single_tag_title ( '' , false );
	} else if ( is_author() ) {
		$page_title = get_the_author_meta('display_name');
	
	} else return;
	
	?>

	<?php if ( !$page_title ) return; ?>
	<div class="page-title-box main-page-title clearfix">
		<h1 class="page-title"><?php echo $page_title; ?></h1>
		<?php if ( is_category() && $data['hb_enable_rss'] ) { 
			$category = get_category( get_query_var( 'cat' ) );
			$cat_id = $category->cat_ID;
			?>
			<a href="<?php echo get_category_feed_link( $cat_id ); ?>" class="cat-rss floatright" original-title="<?php _e('RSS Feed' , 'hbthemes'); ?>"><span class="icon-rss"></span></a>
		<?php } ?>
	</div>
	
	<?php if ( $page_subtitle ) { ?>
	<h3 class="sub-title floatleft"><?php echo $page_subtitle; ?></h3>
	<div class="clear"></div>
	<?php }	
	
	do_action('hb_after_title');
}
add_action('page_custom_before_content' , 'hb_archives_title', 10, 1);
?>