<?php
/*
 * Plugin Name: (BulletPress) Author Widget
 * Plugin URI: http://www.hb-themes.com
 * Description: A widget that displays an author
 * Version: 1.0
 * Author: HB-Themes
 * Author URI: http://www.hb-themes.com
 */

/*
 * Add function to widgets_init that'll load our widget.
 */
add_action( 'widgets_init', 'hb_author_widgets' );

/*
 * Register widget.
 */
function hb_author_widgets() {
	register_widget( 'HB_Author_Widget' );
}

/*
 * Widget class.
 */
class hb_author_widget extends WP_Widget {

	/* ---------------------------- */
	/* -------- Widget setup -------- */
	/* ---------------------------- */
	
	function HB_Author_Widget() {
	
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'hb-author-widget', 'description' => __('A widget that displays an author.', 'hbthemes') );
		$control_ops = array ();
		/* Create the widget. */
		$this->WP_Widget( 'hb_author_widget', __('[HB] Author','hbthemes'), $widget_ops, $control_ops );
	}

	/* ---------------------------- */
	/* ------- Display Widget -------- */
	/* ---------------------------- */
	
	function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$author = $instance['author'];
		
		/* Before widget (defined by themes). */
		echo $before_widget;
		
		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;

		if ( $author != 'random')
			$user = get_user_by('login', $author);
		else {
			$user = get_users();
			shuffle($user);
			$user = $user[0];
		}

		?>
		<!-- BEGIN .author-box -->
		<div class="author-box-content clearfix">
			<?php 
				$auth_url = '';
				if ( count_user_posts ( $user->ID ) != 0 ) 
					$auth_url = 'href="' . get_author_posts_url ( $user->ID ) . '"'; 
			?>
			<a <?php echo $auth_url ?> class="author-img-link" title="<?php 
				if ( count_user_posts ( $user->ID ) != 0 ) 
					_e('View articles' , 'hbthemes'); 
				else
					_e('No articles' , 'hbthemes'); ?>">
			<?php echo get_avatar( get_the_author_meta('user_email' , $user->ID) , 112); ?></a>
			
			<!-- BEGIN .author-desc -->
			<div class="author-desc">
				<h3 class="author-title">
					<a <?php echo $auth_url; ?>>
						<?php the_author_meta ( 'display_name' , $user->ID ); ?>
					</a>
					
					<?php /*<span class="user-posts">
						<?php echo '(' . count_user_posts ( $user->ID ); 
						if ( count_user_posts ( $user->ID ) > 1 || count_user_posts ( $user->ID ) == 0 )
							_e(' articles', 'hbthemes');
						else 
							_e(' article', 'hbthemes'); 
						echo ')';?>
					</span>
					*/?>
				</h3>
				<div class="author-text">
					<?php the_author_meta ( 'user_description' , $user->ID ); ?>
					<?php //echo count_user_posts ( $user->ID ); ?>
				</div>
			</div>
			<!-- END .author-desc -->
			
			<?php $user_soc = hb_get_user_socials ( $user->ID ); ?>
			<ul class="ssm">
				<?php foreach ( $user_soc as $soc => $soc_details ) { 
					if ( $soc_details['soc_link'] != '' ) { ?>
						<li class="<?php echo $soc; ?>" title="<?php echo $soc_details['soc_name']; ?>"><a href="<?php echo $soc_details['soc_link']; ?>"><?php echo $soc; ?></a></li>
					<?php }	
					} ?>
			</ul>
			
		</div>
		<!-- END .author-box -->
		<?php
		
		/* Display widget */
		echo $after_widget;
	}

	/* ---------------------------- */
	/* ------- Update Widget -------- */
	/* ---------------------------- */
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['author'] = $new_instance['author'];

		/* No need to strip tags for.. */

		return $instance;
	}
	
	/* ---------------------------- */
	/* ------- Widget Settings ------- */
	/* ---------------------------- */
	
	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	 
	function form( $instance ) {

	
		/* Set up some default widget settings. */
		$defaults = array(
		'title' => 'Author Widget',
		'author' => '',
		);

		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:','hbthemes'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>
		
		<?php
		$users = get_users ( 'orderby=display_name&who=authors');
		?>

		<!-- Style: Select -->
		<p>
			<label for="<?php echo $this->get_field_id( 'author' ); ?>"><?php _e( 'Choose Author: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'author' ); ?>" name="<?php echo $this->get_field_name( 'author' ); ?>">
				<option <?php if ( 'random' == $instance['author'] ) echo ' selected="selected"';?> value='random'><?php _e('Random','hbthemes'); ?></option>
				<?php if ( $users ) { 
					foreach ( $users as $usr ) { ?>
						<option <?php if ( $usr->user_login == $instance['author'] ) echo ' selected="selected"';?> value='<?php echo $usr->user_login; ?>'><?php echo $usr->display_name; ?></option>
					<?php } 
				}?>
			</select>
		</p>

		
	<?php
	}
}
?>