<?php
/*
 * Plugin Name: (BulletPress) News In Pictures Widget
 * Plugin URI: http://www.hb-themes.com
 * Description: A widget that displays posts by their featured image in 2 columns, medium sized.
 * Version: 1.0
 * Author: HB-Themes
 * Author URI: http://www.hb-themes.com
 */

/*
 * Add function to widgets_init that'll load our widget.
 */
add_action( 'widgets_init', 'hb_medium_thumb_posts_widgets' );

/*
 * Register widget.
 */
function hb_medium_thumb_posts_widgets() {
	register_widget( 'HB_Medium_Thumb_Posts_Widget' );
}

/*
 * Widget class.
 */
class hb_medium_thumb_posts_widget extends WP_Widget {

	/* ---------------------------- */
	/* -------- Widget setup -------- */
	/* ---------------------------- */
	
	function HB_Medium_Thumb_Posts_Widget() {
	
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'hb-news-in-pictures-widget', 'description' => __('A widget that displays your posts by their featured image.', 'hbthemes') );
		$control_ops = array ();
		/* Create the widget. */
		$this->WP_Widget( 'hb_medium_thumb_posts_widget', __('[HB] News in Pictures','hbthemes'), $widget_ops, $control_ops );
	}

	/* ---------------------------- */
	/* ------- Display Widget -------- */
	/* ---------------------------- */
	
	function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$count = $instance['count'];
		$category = $instance['category'];
		$order = $instance['order'];
		$orderby = $instance['orderby'];
		
		/* Before widget (defined by themes). */
		echo $before_widget;
		
		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;
		
		$category = str_replace ( "nip_" , "" , $category );
		if ( !$count ) $count = -1;
		if ( $category ) query_posts ( 'posts_per_page=' . $count . '&cat=' . $category . '&orderby=' . $orderby . '&order=' . $order );
		else query_posts ( 'posts_per_page=' . $count . '&orderby=' . $orderby . '&order=' . $order );
		
		/* Display widget */
		if ( have_posts() ) : ?>
			<ul class="news-in-pictures clearfix">
			<?php while ( have_posts() ) : the_post(); 
				$thumb = get_post_thumbnail_id();
				$img_url = wp_get_attachment_url( $thumb,'full'); //get img 
				$image = hb_resize( $img_url, 290, 192, true ); 
			?>
			<?php if ($image) { ?>
			<li>
				<a href="<?php the_permalink(); ?>" class="preload" original-title="<?php the_title(); ?>">
					<img src="<?php echo $image; ?>" />
				</a>
			</li>
			<?php } ?>
			<?php endwhile; ?>
			</ul>
		<?php
		endif;
		wp_reset_query();
		
		echo $after_widget;
	}

	/* ---------------------------- */
	/* ------- Update Widget -------- */
	/* ---------------------------- */
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['count'] = $new_instance['count'];
		$instance['category'] = $new_instance['category'];
		$instance['order'] = $new_instance['order'];
		$instance['orderby'] = $new_instance['orderby'];

		/* No need to strip tags for.. */

		return $instance;
	}
	
	/* ---------------------------- */
	/* ------- Widget Settings ------- */
	/* ---------------------------- */
	
	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	 
	function form( $instance ) {

	
		/* Set up some default widget settings. */
		$defaults = array(
		'title' => 'News In Pictures',
		'count' => '10',
		'category' => '',
		'order'=>'DESC',
		'orderby'=>'date'
		);
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:','hbthemes'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>
		
		<!-- Count: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'count' ); ?>"><?php _e('Post Count: ','hbthemes'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'count' ); ?>" name="<?php echo $this->get_field_name( 'count' ); ?>" value="<?php echo $instance['count']; ?>" />
		</p>
		
		<?php 
		$posts_categories = array();
		$of_categories_obj = get_categories('hide_empty=0');
		?>

		<!-- Category: Select -->
		<p>
			<label for="<?php echo $this->get_field_id( 'category' ); ?>"><?php _e( 'Post Category: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'category' ); ?>" name="<?php echo $this->get_field_name( 'category' ); ?>">
				<option value="" <?php if ( ""==$instance['category'] ) echo ' selected="selected"'; ?>><?php _e('None','hbthemes'); ?></option>
				<?php
				foreach ($of_categories_obj as $of_cat) { ?>
					<option value="nip_<?php echo $of_cat->cat_ID; ?>" <?php if ("nip_" . $of_cat->cat_ID == $instance['category'] ) echo ' selected="selected"';?>><?php echo $of_cat->cat_name; ?></option>
				<?php } 
				?>
			</select>
		</p>
		
		<!-- Orderby: Select -->
		<p>
			<label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php _e( 'Post Orderby: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'orderby' ); ?>" name="<?php echo $this->get_field_name( 'orderby' ); ?>">
				<option value="date" <?php if ("date"==$instance['orderby'] ) echo 'selected="selected"'; ?>><?php _e('Date','hbthemes'); ?></option>
				<option value="rand" <?php if ("rand"==$instance['orderby'] ) echo 'selected="selected"'; ?>><?php _e('Random','hbthemes'); ?></option>
				<option value="title" <?php if ("title"==$instance['orderby'] ) echo 'selected="selected"'; ?>><?php _e('Title','hbthemes'); ?></option>
				<option value="menu_order" <?php if ("menu_order"==$instance['orderby'] ) echo 'selected="selected"'; ?>><?php _e('Menu Order','hbthemes'); ?></option>
				<option value="comment_count" <?php if ("comment_count"==$instance['orderby'] ) echo 'selected="selected"'; ?>><?php _e('Comment Count','hbthemes'); ?></option>
			</select>
		</p>
		
		<!-- Order: Select -->
		<p>
			<label for="<?php echo $this->get_field_id( 'order' ); ?>"><?php _e( 'Post Order: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'order' ); ?>" name="<?php echo $this->get_field_name( 'order' ); ?>">
				<option value="DESC" <?php if ("DESC"==$instance['order'] ) echo 'selected="selected"'; ?>><?php _e('DESC','hbthemes'); ?></option>
				<option value="ASC" <?php if ("ASC"==$instance['order'] ) echo 'selected="selected"'; ?>><?php _e('ASC','hbthemes'); ?></option>
			</select>
		</p>

		
	<?php
	}
}
?>