<?php
/*
 * Plugin Name: (BulletPress) Latest Posts Slider
 * Plugin URI: http://www.hb-themes.com
 * Description: A widget that displays latest posts slider.
 * Version: 1.0
 * Author: HB-Themes
 * Author URI: http://www.hb-themes.com
 */

/*
 * Add function to widgets_init that'll load our widget.
 */
add_action( 'widgets_init', 'hb_post_slider_widgets' );

/*
 * Register widget.
 */
function hb_post_slider_widgets() {
	register_widget( 'HB_Post_Slider_Widget' );
}

/*
 * Widget class.
 */
class hb_post_slider_widget extends WP_Widget {

	/* ---------------------------- */
	/* -------- Widget setup -------- */
	/* ---------------------------- */
	
	function HB_Post_Slider_Widget() {
	
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'hb_post_slider_widget', 'description' => __('A widget that displays slider with posts.', 'hbthemes') );
		$control_ops = array ();
		/* Create the widget. */
		$this->WP_Widget( 'hb_post_slider_widget', __('[HB] Posts Slider','hbthemes'), $widget_ops, $control_ops );
	}

	/* ---------------------------- */
	/* ------- Display Widget -------- */
	/* ---------------------------- */
	
	function widget( $args, $instance ) {
		extract( $args );
		global $wp_query;

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$count = $instance['count'];
		$review = $instance['review'];
		$cat = $instance['cat'];

		$show_excerpt = $instance['show_excerpt'];
		$show_views = $instance['show_views'];
		$show_author = $instance['show_author'];
		$show_date = $instance['show_date'];
		$show_category = $instance['show_category'];
		$show_comments = $instance['show_comments'];
		$order = $instance['order'];
		
		/* Before widget (defined by themes). */
		echo $before_widget;
		
		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;

		if ( !$count ) $count = -1;
		$cat = str_replace ( 'nip_' , '', $cat);
		
		$review = $review=="y" ? true : false;
		$show_excerpt = $show_excerpt=="y" ? true : false;
		$show_views = $show_views=="y" ? true : false;
		$show_author = $show_author=="y" ? true : false;
		$show_date = $show_date=="y" ? true : false;
		$show_category = $show_category=="y" ? true : false;
		$show_comments = $show_comments=="y" ? true : false;

		hb_post_slider ( $count , $cat , $show_excerpt, $show_views, true, $review, $show_author, $show_date, $show_category, $show_comments, '<span class="delimiter">&middot;</span>', 10, $order );
		
		echo $after_widget;
	}
	
	

	/* ---------------------------- */
	/* ------- Update Widget -------- */
	/* ---------------------------- */
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['count'] = $new_instance['count'];
		$instance['cat'] = implode(',' , $new_instance['cat']  );
		$instance['review'] = $new_instance['review'];

		$instance['show_excerpt'] = $new_instance['show_excerpt'];
		$instance['show_views'] = $new_instance['show_views'];
		$instance['show_author'] = $new_instance['show_author'];
		$instance['show_date'] = $new_instance['show_date'];
		$instance['show_category'] = $new_instance['show_category'];
		$instance['show_comments'] = $new_instance['show_comments'];
		$instance['order'] = $new_instance['order'];
		/* No need to strip tags for.. */

		return $instance;
	}
	
	/* ---------------------------- */
	/* ------- Widget Settings ------- */
	/* ---------------------------- */
	
	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	 
	function form( $instance ) {

	
		/* Set up some default widget settings. */
		$defaults = array(
		'title' => 'Post Slider',
		'count' => '5',
		'cat' => '',
		'review'=>'',
		'show_excerpt'=>'n',
		'show_views'=>'',
		'show_author'=>'',
		'show_date' =>'',
		'show_category'=>'',
		'show_comments'=>'',
		'order'=>'',
		);
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:','hbthemes'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>
	    
		<p>
			<label for="<?php echo $this->get_field_id( 'count' ); ?>"><?php _e('Number of posts in the slider.','hbthemes'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'count' ); ?>" name="<?php echo $this->get_field_name( 'count' ); ?>" value="<?php echo $instance['count']; ?>" />
		</p>

		<!-- Review Start: Select -->
		<p>
			<label for="<?php echo $this->get_field_id( 'review' ); ?>"><?php _e( 'Show "Review" stars rating: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'review' ); ?>" name="<?php echo $this->get_field_name( 'review' ); ?>">
				<option value="y" <?php if ( "y"==$instance['review'] ) echo ' selected="selected"'; ?>><?php _e('Yes','hbthemes'); ?></option>
				<option value="n" <?php if ( "n"==$instance['review'] ) echo ' selected="selected"'; ?>><?php _e('No','hbthemes'); ?></option>
			</select>
		</p>

	    <?php 
		$posts_categories = array();
		$of_categories_obj = get_categories('hide_empty=0');
		?>

		<!-- Cat: Select -->
		<p>
			<?php $cats_id = explode ( ',-' , $instance['cat'] ) ; ?>
			<label for="<?php echo $this->get_field_id( 'cat' ); ?>"><?php _e( 'Specify Post Category: ','hbthemes'); ?></label>
			<select multiple="multiple" id="<?php echo $this->get_field_id( 'cat' ); ?>[]" name="<?php echo $this->get_field_name( 'cat' ); ?>[]">
				<option value="" <?php if ( ""==$instance['cat'] ) echo ' selected="selected"'; ?>><?php _e('None','hbthemes'); ?></option>
				<?php
				foreach ($of_categories_obj as $of_cat) { ?>
					<option value="nip_<?php echo $of_cat->cat_ID; ?>"  <?php if ( in_array( "nip_".$of_cat->cat_ID , $cats_id ) ) { echo ' selected="selected"' ; } ?>><?php echo $of_cat->cat_name; ?></option>
				<?php } 
				?>
			</select>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'show_views' ); ?>"><?php _e( 'Show View Count: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'show_views' ); ?>" name="<?php echo $this->get_field_name( 'show_views' ); ?>">
				<option value="y" <?php if ( "y"==$instance['show_views'] ) echo ' selected="selected"'; ?>><?php _e('Yes','hbthemes'); ?></option>
				<option value="n" <?php if ( "n"==$instance['show_views'] ) echo ' selected="selected"'; ?>><?php _e('No','hbthemes'); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'show_excerpt' ); ?>"><?php _e( 'Show Excerpt: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'show_excerpt' ); ?>" name="<?php echo $this->get_field_name( 'show_excerpt' ); ?>">
				<option value="y" <?php if ( "y"==$instance['show_excerpt'] ) echo ' selected="selected"'; ?>><?php _e('Yes','hbthemes'); ?></option>
				<option value="n" <?php if ( "n"==$instance['show_excerpt'] ) echo ' selected="selected"'; ?>><?php _e('No','hbthemes'); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'show_author' ); ?>"><?php _e( 'Show Author: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'show_author' ); ?>" name="<?php echo $this->get_field_name( 'show_author' ); ?>">
				<option value="y" <?php if ( "y"==$instance['show_author'] ) echo ' selected="selected"'; ?>><?php _e('Yes','hbthemes'); ?></option>
				<option value="n" <?php if ( "n"==$instance['show_author'] ) echo ' selected="selected"'; ?>><?php _e('No','hbthemes'); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'show_date' ); ?>"><?php _e( 'Show Date: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>">
				<option value="y" <?php if ( "y"==$instance['show_date'] ) echo ' selected="selected"'; ?>><?php _e('Yes','hbthemes'); ?></option>
				<option value="n" <?php if ( "n"==$instance['show_date'] ) echo ' selected="selected"'; ?>><?php _e('No','hbthemes'); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'show_category' ); ?>"><?php _e( 'Show Categories: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'show_category' ); ?>" name="<?php echo $this->get_field_name( 'show_category' ); ?>">
				<option value="y" <?php if ( "y"==$instance['show_category'] ) echo ' selected="selected"'; ?>><?php _e('Yes','hbthemes'); ?></option>
				<option value="n" <?php if ( "n"==$instance['show_category'] ) echo ' selected="selected"'; ?>><?php _e('No','hbthemes'); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'show_comments' ); ?>"><?php _e( 'Show Comment count: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'show_comments' ); ?>" name="<?php echo $this->get_field_name( 'show_comments' ); ?>">
				<option value="y" <?php if ( "y"==$instance['show_comments'] ) echo ' selected="selected"'; ?>><?php _e('Yes','hbthemes'); ?></option>
				<option value="n" <?php if ( "n"==$instance['show_comments'] ) echo ' selected="selected"'; ?>><?php _e('No','hbthemes'); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'order' ); ?>"><?php _e( 'Order Criteria: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'order' ); ?>" name="<?php echo $this->get_field_name( 'order' ); ?>">
				<option value="recent" <?php if ( "recent"==$instance['order'] ) echo ' selected="selected"'; ?>><?php _e('Recent','hbthemes'); ?></option>
				<option value="comment_count" <?php if ( "comment_count"==$instance['order'] ) echo ' selected="selected"'; ?>><?php _e('Comment Count','hbthemes'); ?></option>
				<option value="views" <?php if ( "views"==$instance['order'] ) echo ' selected="selected"'; ?>><?php _e('Views','hbthemes'); ?></option>
				<option value="random" <?php if ( "random"==$instance['order'] ) echo ' selected="selected"'; ?>><?php _e('Random','hbthemes'); ?></option>
				<option value="reviews" <?php if ( "reviews"==$instance['order'] ) echo ' selected="selected"'; ?>><?php _e('Reviews','hbthemes'); ?></option>
			</select>
		</p>

	<?php
	}
}

?>