<?php
/*
 * Plugin Name: (BulletPress) Promo Box Widget
 * Plugin URI: http://www.hb-themes.com
 * Description: A widget that displays a light or dark promo box
 * Version: 1.0
 * Author: HB-Themes
 * Author URI: http://www.hb-themes.com
 */

/*
 * Add function to widgets_init that'll load our widget.
 */
add_action( 'widgets_init', 'hb_promo_box_widget' );

/*
 * Register widget.
 */
function hb_promo_box_widget() {
	register_widget( 'HB_Promo_Box_Widget' );
}

/*
 * Widget class.
 */
class hb_promo_box_widget extends WP_Widget {

	/* ---------------------------- */
	/* -------- Widget setup -------- */
	/* ---------------------------- */
	
	function HB_Promo_Box_Widget() {
	
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'hb-promo-box-widget', 'description' => __('A widget that displays a light or dark promo box.', 'hbthemes') );
		$control_ops = array ();
		/* Create the widget. */
		$this->WP_Widget( 'hb_promo_box_widget', __('[HB] Promo Box','hbthemes'), $widget_ops, $control_ops );
	}

	/* ---------------------------- */
	/* ------- Display Widget -------- */
	/* ---------------------------- */
	
	function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$content = $instance['content'];
		$style = $instance['style'];
		
		/* Before widget (defined by themes). */
		echo $before_widget;
		
		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;
		
		/* Display widget */
		?>
		<section class="hb-promo-box clearfix <?php echo strtolower($style); ?>">
			<?php echo do_shortcode($content); ?>
		</section>
		<?php
		echo $after_widget;
	}

	/* ---------------------------- */
	/* ------- Update Widget -------- */
	/* ---------------------------- */
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['content'] = $new_instance['content'];
		$instance['style'] = $new_instance['style'];

		/* No need to strip tags for.. */

		return $instance;
	}
	
	/* ---------------------------- */
	/* ------- Widget Settings ------- */
	/* ---------------------------- */
	
	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	 
	function form( $instance ) {

	
		/* Set up some default widget settings. */
		$defaults = array(
		'title' => 'Promo Box Widget',
		'content' => '',
		'style' => 'light',
		);
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:','hbthemes'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>
		
		<!-- Content: Textarea Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'content' ); ?>"><?php _e('Promo Box Content: ','hbthemes'); ?></label>
			<textarea class="widefat" id="<?php echo $this->get_field_id( 'content' ); ?>" name="<?php echo $this->get_field_name( 'content' ); ?>"><?php echo $instance['content']; ?></textarea
		</p>

		<!-- Style: Select -->
		<p>
			<label for="<?php echo $this->get_field_id( 'style' ); ?>"><?php _e( 'Promo Box Style: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'style' ); ?>" name="<?php echo $this->get_field_name( 'style' ); ?>">
				<option <?php if (__('Light','hbthemes') == $instance['style'] ) echo ' selected="selected"';?>><?php _e('Light','hbthemes'); ?></option>
				<option <?php if (__('Dark','hbthemes') == $instance['style'] ) echo ' selected="selected"';?>><?php _e('Dark','hbthemes'); ?></option>
			</select>
		</p>

		
	<?php
	}
}
?>