<?php
/*
 * Plugin Name: (BulletPress) Random Posts Widget
 * Plugin URI: http://www.hb-themes.com
 * Description: A widget that displays a random list of posts.
 * Version: 1.0
 * Author: HB-Themes
 * Author URI: http://www.hb-themes.com
 */

/*
 * Add function to widgets_init that'll load our widget.
 */
add_action( 'widgets_init', 'hb_random_posts_widgets' );

/*
 * Register widget.
 */
function hb_random_posts_widgets() {
	register_widget( 'HB_Random_Posts_Widget' );
}

/*
 * Widget class.
 */
class hb_random_posts_widget extends WP_Widget {

	/* ---------------------------- */
	/* -------- Widget setup -------- */
	/* ---------------------------- */
	
	function HB_Random_Posts_Widget() {
	
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'hb-random-posts-widget', 'description' => __('A widget that displays a random list of posts.', 'hbthemes') );
		$control_ops = array ();
		/* Create the widget. */
		$this->WP_Widget( 'hb_random_posts_widget', __('[HB] Random Posts','hbthemes'), $widget_ops, $control_ops );
	}

	/* ---------------------------- */
	/* ------- Display Widget -------- */
	/* ---------------------------- */
	
	function widget( $args, $instance ) {
		extract( $args );
		global $wp_query;

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$count = $instance['count'];
		$exclude = $instance['exclude'];
		$exclude = str_replace ( 'nip_' , '' , $exclude );
		$review = $instance['review'];
		
		/* Before widget (defined by themes). */
		echo $before_widget;
		
		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;
		
		if ( $exclude ) $query = new WP_Query('posts_per_page=' . $count . '&cat=' . $exclude . '&orderby=rand');
		else $query = new WP_Query('posts_per_page=' . $count . '&orderby=rand');

		hb_post_list ( $query , true , true, true, false, false, $review );
		wp_reset_query();
		
		echo $after_widget;
	}
	
	

	/* ---------------------------- */
	/* ------- Update Widget -------- */
	/* ---------------------------- */
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['count'] = $new_instance['count'];
		$instance['exclude'] = implode(',' , $new_instance['exclude']  );
		$instance['review'] = $new_instance['review'];
		
		/* No need to strip tags for.. */

		return $instance;
	}
	
	/* ---------------------------- */
	/* ------- Widget Settings ------- */
	/* ---------------------------- */
	
	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	 
	function form( $instance ) {

	
		/* Set up some default widget settings. */
		$defaults = array(
		'title' => 'Random Posts Widget',
		'count' => '5',
		'exclude'=>'',
		'review' => 'n',
		);
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:','hbthemes'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>
		
		<!-- Post count: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'count' ); ?>"><?php _e('Post List Count:','hbthemes'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'count' ); ?>" name="<?php echo $this->get_field_name( 'count' ); ?>" value="<?php echo $instance['count']; ?>" />
		</p>

		<!-- Review Start: Select -->
		<p>
			<label for="<?php echo $this->get_field_id( 'review' ); ?>"><?php _e( 'Show "Review" stars rating: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'review' ); ?>" name="<?php echo $this->get_field_name( 'review' ); ?>">
				<option value="y" <?php if ( "y"==$instance['review'] ) echo ' selected="selected"'; ?>><?php _e('Yes','hbthemes'); ?></option>
				<option value="n" <?php if ( "n"==$instance['review'] ) echo ' selected="selected"'; ?>><?php _e('No','hbthemes'); ?></option>
			</select>
		</p>

		<?php 
		$posts_categories = array();
		$of_categories_obj = get_categories('hide_empty=0');
		?>

		<!-- Exclude: Select -->
		<p>
			<?php $cats_id = explode ( ',' , $instance['exclude'] ) ; ?>
			<label for="<?php echo $this->get_field_id( 'exclude' ); ?>"><?php _e( 'Specify Post Category: ','hbthemes'); ?></label>
			<select multiple="multiple" id="<?php echo $this->get_field_id( 'exclude' ); ?>[]" name="<?php echo $this->get_field_name( 'exclude' ); ?>[]">
				<option value="" <?php if ( ""==$instance['exclude'] ) echo ' selected="selected"'; ?>><?php _e('None','hbthemes'); ?></option>
				<?php
				foreach ($of_categories_obj as $of_cat) { ?>
					<option value="nip_<?php echo $of_cat->cat_ID; ?>"  <?php if ( in_array( "nip_".$of_cat->cat_ID , $cats_id ) ) { echo ' selected="selected"' ; } ?>><?php echo $of_cat->cat_name; ?></option>
				<?php } 
				?>
			</select>
		</p>
		
		
		
	<?php
	}
}

?>