<?php
/*
 * Plugin Name: (BulletPress) Custom Tabs Widget
 * Plugin URI: http://www.hb-themes.com
 * Description: A widget that displays 4 different tabs: Recent, Popular, Most Viewed posts and Tag Cloud.
 * Version: 1.0
 * Author: HB-Themes
 * Author URI: http://www.hb-themes.com
 */

/*
 * Add function to widgets_init that'll load our widget.
 */
add_action( 'widgets_init', 'hb_custom_tabs_widgets' );

/*
 * Register widget.
 */
function hb_custom_tabs_widgets() {
	register_widget( 'HB_Custom_Tabs_Widget' );
}

/*
 * Widget class.
 */
class hb_custom_tabs_widget extends WP_Widget {

	/* ---------------------------- */
	/* -------- Widget setup -------- */
	/* ---------------------------- */
	
	function HB_Custom_Tabs_Widget() {
	
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'hb-custom-tabs-widget', 'description' => __('A widget that displays 4 tabs: Recent, Popular, Most Viewed posts and Tag Cloud.', 'hbthemes') );
		$control_ops = array ();
		/* Create the widget. */
		$this->WP_Widget( 'hb_custom_tabs_widget', __('[HB] Tabs','hbthemes'), $widget_ops, $control_ops );
	}

	/* ---------------------------- */
	/* ------- Display Widget -------- */
	/* ---------------------------- */
	
	function widget( $args, $instance ) {
		extract( $args );
		global $wp_query;

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$recent = $instance['recent'];
		$popular = $instance['popular'];
		$viewed = $instance['viewed'];
		$tags = $instance['tags'];
		$count = $instance['count'];
		$review = $instance['review'];
		$style = $instance['style'];
		
		$recent = $recent == 'y' ? true: false;
		$popular = $popular == 'y' ? true: false;
		$viewed = $viewed == 'y' ? true: false;
		$tags = $tags == 'y' ? true : false;
		$review = $review == 'y' ? true : false;
		
		/* Before widget (defined by themes). */
		echo $before_widget;
		
		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;
		
		if ( !$count ) $count = '-1';
		
		if ( $recent || $popular || $viewed ) {
		?>
		<div class="hb-tabs <?php echo $style; ?> clearfix autop">
			<ul class="titles clearfix autop">
				<?php if ( $recent ) { ?>
				<li class="opened"><a href="#"><?php _e('Recent','hbthemes'); ?></a></li>
				<?php } 
				if ( $popular ) { ?>
				<li><a href="#"><?php _e('Popular','hbthemes'); ?></a></li>
				<?php } 
				if ( $viewed ) { ?>
				<li><a href="#"><?php _e('Most Viewed','hbthemes'); ?></a></li>
				<?php } ?>
				<?php if ( $tags ) { ?>
				<li><a href="#"><?php _e('Tags','hbthemes'); ?></a></li>
				<?php } ?>
			</ul>
			<div class="contents clearfix">
				<?php if ( $recent ) { 
					$query = new WP_Query('orderby=date&order=DESC&posts_per_page=' . $count);
					hb_post_list ( $query , true , false, true, false, false, $review);
					wp_reset_query();
				} 
				if ( $popular ) { 
					$query = new WP_query('orderby=comment_count&order=DESC&posts_per_page=' . $count);
					hb_post_list ( $query , true , false, true, false, false, $review );
					wp_reset_query();
				}
				if ( $viewed ) {
				
					$query = get_most_viewed_post_query($count);
					hb_post_list ( $query , false , true, true, false, false, $review);
					wp_reset_query();
				}
				if ( $tags ) { ?>
					<div class="tagcloud">
					<?php wp_tag_cloud('smallest=13&largest=13&unit=px'); ?>
					</div>
				<?php }
				?>
			</div>
		</div>
		<?php
		}
		
		echo $after_widget;
	}
	
	

	/* ---------------------------- */
	/* ------- Update Widget -------- */
	/* ---------------------------- */
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['recent'] = $new_instance['recent'];
		$instance['popular'] = $new_instance['popular'];
		$instance['viewed'] = $new_instance['viewed'];
		$instance['tags'] = $new_instance['tags'];
		$instance['count'] = $new_instance['count'];
		$instance['style'] = $new_instance['style'];
		$instance['review'] = $new_instance['review'];

		/* No need to strip tags for.. */

		return $instance;
	}
	
	/* ---------------------------- */
	/* ------- Widget Settings ------- */
	/* ---------------------------- */
	
	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	 
	function form( $instance ) {

	
		/* Set up some default widget settings. */
		$defaults = array(
		'title' => 'Tabs Widget',
		'count' => '5',
		'style' => 'light',
		'recent' => 'y',
		'popular' => 'y',
		'viewed'=>'y',
		'tags'=>'y',
		'review'=>'n'
		);
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:','hbthemes'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>
		
		<!-- Post count: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'count' ); ?>"><?php _e('Post Count in each tab:','hbthemes'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'count' ); ?>" name="<?php echo $this->get_field_name( 'count' ); ?>" value="<?php echo $instance['count']; ?>" />
		</p>
		
		<!-- Recent: Select -->
		<p>
			<label for="<?php echo $this->get_field_id( 'recent' ); ?>"><?php _e( 'Show "Recent" Tab: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'recent' ); ?>" name="<?php echo $this->get_field_name( 'recent' ); ?>">
				<option value="y" <?php if ( "y"==$instance['recent'] ) echo ' selected="selected"'; ?>><?php _e('Yes','hbthemes'); ?></option>
				<option value="n" <?php if ( "n"==$instance['recent'] ) echo ' selected="selected"'; ?>><?php _e('No','hbthemes'); ?></option>
			</select>
		</p>
		
		<!-- Popular: Select -->
		<p>
			<label for="<?php echo $this->get_field_id( 'popular' ); ?>"><?php _e( 'Show "Popular" Tab: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'popular' ); ?>" name="<?php echo $this->get_field_name( 'popular' ); ?>">
				<option value="y" <?php if ( "y"==$instance['popular'] ) echo ' selected="selected"'; ?>><?php _e('Yes','hbthemes'); ?></option>
				<option value="n" <?php if ( "n"==$instance['popular'] ) echo ' selected="selected"'; ?>><?php _e('No','hbthemes'); ?></option>
			</select>
		</p>
		
		<!-- Most Viewed: Select -->
		<p>
			<label for="<?php echo $this->get_field_id( 'viewed' ); ?>"><?php _e( 'Show "Most Viewed" Tab: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'viewed' ); ?>" name="<?php echo $this->get_field_name( 'viewed' ); ?>">
				<option value="y" <?php if ( "y"==$instance['viewed'] ) echo ' selected="selected"'; ?>><?php _e('Yes','hbthemes'); ?></option>
				<option value="n" <?php if ( "n"==$instance['viewed'] ) echo ' selected="selected"'; ?>><?php _e('No','hbthemes'); ?></option>
			</select>
		</p>


		<!-- Tag Cloud: Select -->
		<p>
			<label for="<?php echo $this->get_field_id( 'tags' ); ?>"><?php _e( 'Show "Tags" Tab: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'tags' ); ?>" name="<?php echo $this->get_field_name( 'tags' ); ?>">
				<option value="y" <?php if ( "y"==$instance['tags'] ) echo ' selected="selected"'; ?>><?php _e('Yes','hbthemes'); ?></option>
				<option value="n" <?php if ( "n"==$instance['tags'] ) echo ' selected="selected"'; ?>><?php _e('No','hbthemes'); ?></option>
			</select>
		</p>

		<!-- Review Start: Select -->
		<p>
			<label for="<?php echo $this->get_field_id( 'review' ); ?>"><?php _e( 'Show "Review" stars rating: ','hbthemes'); ?></label>
			<select id="<?php echo $this->get_field_id( 'review' ); ?>" name="<?php echo $this->get_field_name( 'review' ); ?>">
				<option value="y" <?php if ( "y"==$instance['review'] ) echo ' selected="selected"'; ?>><?php _e('Yes','hbthemes'); ?></option>
				<option value="n" <?php if ( "n"==$instance['review'] ) echo ' selected="selected"'; ?>><?php _e('No','hbthemes'); ?></option>
			</select>
		</p>
		
		
	<?php
	}
}

function hb_post_list( $query , $comments = false, $likes = false, $date = false, $categories = false, $posted_by = false, $review = false) {
		if ( $query->have_posts() ) :
		?>
		<div>
			<ul class="post-list">
				<?php while ( $query->have_posts() ) : $query->the_post(); 
					?>
					<li>
					<div class="post-thumb">
						<a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>" class="preload">
							<?php hb_post_featured_image( get_the_ID() , 160, 106 ); ?>
						</a>
					</div>
					<?php if ( $review ) { ?>
						<?php if ( get_post_meta( get_the_ID(), 'hb_enable_review', true) ) {
							$final_review_mark = get_post_meta ( get_the_ID() , 'hb_final_review_value' , true);
							?>
							<div class="stars-wrapper">
								<span class="omc-criteria-star-under">
									<span class="omc-criteria-star-top" style="width:<?php echo $final_review_mark; ?>%"></span>
								</span>
							</div>
							<?php } ?>
					<?php } ?>
			
					<div class="post-content">
						<h3><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a></h3>
						<span class="entry-meta">

							<?php
							hb_post_meta_details( get_the_ID(), $date, $posted_by, $categories, $comments, $likes);
							?>

						</span>
					</div>
					</li>
				<?php endwhile; ?>
			</ul>
		</div>
		<?php 
		endif;
	}
?>